<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs_CZ" version="2.0">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>Version %1</source>
        <translation>Verze %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 je distribuován jako svobodný program, avšak vývoj zabírá značné množství času.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Prosím &lt;a href=&apos;%1&apos;&gt;přispějte&lt;/a&gt; kvůli podpoře pokračování ve vývoji %2.</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Vydáno pod licencií &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O aplikaci</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>Vše jste kdy chtěli vědět o %1 a nikdy jste se neodvážili se zeptat</translation>
    </message>
    <message>
        <source>You may want to try my other apps as well:</source>
        <translation>Je možné, že vás zaujmou i moje ostatní programy:</translation>
    </message>
    <message>
        <source>%1, a YouTube app</source>
        <translation>%1, aplikace pro YouTube</translation>
    </message>
    <message>
        <source>%1, a YouTube music player</source>
        <translation>%1, přehrávač hudby z YouTube</translation>
    </message>
    <message>
        <source>Translate %1 to your native language using %2</source>
        <translation>Přeložte %1 do vašeho mateřského jazyka pomocí %2</translation>
    </message>
    <message>
        <source>Licensed to: %1</source>
        <translation>Licence k: %1</translation>
    </message>
</context>
<context>
    <name>ActivationDialog</name>
    <message>
        <source>Enter your License Details</source>
        <translation>Vložte detaily vaší licence</translation>
    </message>
    <message>
        <source>&amp;Email:</source>
        <translation>&amp;Email:</translation>
    </message>
    <message>
        <source>&amp;Code:</source>
        <translation>&amp;Kód</translation>
    </message>
</context>
<context>
    <name>ActivationView</name>
    <message>
        <source>Please license %1</source>
        <translation>Sežeňte si, prosím, licenci %1</translation>
    </message>
    <message>
        <source>This demo has expired.</source>
        <translation>Platnost demoverze vypršela.</translation>
    </message>
    <message>
        <source>Without a license, the application will expire in %1 days.</source>
        <translation>Bez licence žádost vyprší za %1 dnů</translation>
    </message>
    <message>
        <source>By purchasing the full version, you will also support the hard work I put into creating %1.</source>
        <translation>Zakoupením plné verze také podpoříte práci, která byla vložená do tvorby %1.</translation>
    </message>
    <message>
        <source>Use Demo</source>
        <translation>Použít demoverzi</translation>
    </message>
    <message>
        <source>Enter License</source>
        <translation>Vložit licenci</translation>
    </message>
    <message>
        <source>Buy License</source>
        <translation>Koupit licenci</translation>
    </message>
    <message>
        <source>The full version allows you to add more than %1 tracks to the playlist and listen to your music without interruptions.</source>
        <translation>Plná verze vám do seznamu skladeb umožňuje přidat více než %1 skladeb a poslouchat hudbu bez přerušení.</translation>
    </message>
</context>
<context>
    <name>AlbumInfo</name>
    <message>
        <source>Buy on %1</source>
        <translation>Kupte na %1</translation>
    </message>
    <message>
        <source>Read more</source>
        <translation>Čtěte více</translation>
    </message>
</context>
<context>
    <name>AlbumListView</name>
    <message>
        <source>Artist</source>
        <translation>Umělec</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Název</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Oblíbenost</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Obrácené pořadí</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Třídit podle</translation>
    </message>
</context>
<context>
    <name>ArtistInfo</name>
    <message>
        <source>Read more</source>
        <translation>Čtěte více</translation>
    </message>
</context>
<context>
    <name>ArtistListView</name>
    <message>
        <source>Track Count</source>
        <translation>Počet skladeb</translation>
    </message>
    <message>
        <source>Album Count</source>
        <translation>Počet alb</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Jméno</translation>
    </message>
    <message>
        <source>Year</source>
        <translation>Rok</translation>
    </message>
    <message>
        <source>Popularity</source>
        <translation>Oblíbenost</translation>
    </message>
    <message>
        <source>Reversed Order</source>
        <translation>Obrácené pořadí</translation>
    </message>
    <message>
        <source>Sort by</source>
        <translation>Třídit podle</translation>
    </message>
</context>
<context>
    <name>BreadcrumbWidget</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <source>Go back</source>
        <translation>Jít zpět</translation>
    </message>
</context>
<context>
    <name>ChooseFolderView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Vítejte v &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%1 needs to scan your music collection.</source>
        <translation>%1 potřebuje prohledat vaši hudební sbírku.</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Use iTunes collection</source>
        <translation>Použít sbírku iTunes</translation>
    </message>
    <message>
        <source>Use %1</source>
        <translation>Použít %1</translation>
    </message>
    <message>
        <source>Choose a folder...</source>
        <translation>Vyberte složku...</translation>
    </message>
    <message>
        <source>%1 will connect to the Last.fm web services and pass artist names and album titles in order to fetch covert art, biographies and much more.</source>
        <translation>%1 se připojí k internetové službě Last.fm a projde jména autorů a názvy alb, aby natáhl obaly, biografie a mnohem víc.</translation>
    </message>
    <message>
        <source>If you have privacy concerns about this you can quit now.</source>
        <translation>Pokud máte obavy týkající se soukromí, můžete to okamžitě vypnout.</translation>
    </message>
    <message>
        <source>Where&apos;s your music collection?</source>
        <translation>Kde je vaše hudební sbírka?</translation>
    </message>
    <message>
        <source>Select the location of your music collection.</source>
        <translation>Vyberte umístění vaší hudební sbírky.</translation>
    </message>
    <message>
        <source>Locate your collection</source>
        <translation>Najděte svoji sbírku</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Vyprázdnit</translation>
    </message>
</context>
<context>
    <name>CollectionScanner</name>
    <message>
        <source>A scanning task is already running</source>
        <translation>Prohledávání je už spuštěno</translation>
    </message>
</context>
<context>
    <name>CollectionScannerView</name>
    <message>
        <source>%1 is scanning your music collection.</source>
        <translation>%1 prohledává vaši hudební sbírku.</translation>
    </message>
    <message>
        <source>%1 is using &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; to catalog your music.</source>
        <translation>%1 používá &lt;a href=&apos;%2&apos;&gt;%3&lt;/a&gt; na roztřídění vaší hudby.</translation>
    </message>
    <message>
        <source>This will take time depending on your collection size and network speed.</source>
        <translation>Potrvá to jistou dobu v závislosti na velikosti sbírky a rychlosti připojení.</translation>
    </message>
    <message>
        <source>Go grab a coffee</source>
        <translation>Dejte si kávu</translation>
    </message>
</context>
<context>
    <name>DownloadWidget</name>
    <message>
        <source>Downloading update...</source>
        <translation>Stahování aktualizace...</translation>
    </message>
</context>
<context>
    <name>DropArea</name>
    <message>
        <source>Drop here to append to the playlist</source>
        <translation>Upusťte zde pro přidání do seznamu skladeb</translation>
    </message>
</context>
<context>
    <name>FinderWidget</name>
    <message>
        <source>Artists</source>
        <translation>Umělci</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Alba</translation>
    </message>
    <message>
        <source>Folders</source>
        <translation>Složky</translation>
    </message>
</context>
<context>
    <name>GlobalShortcuts</name>
    <message>
        <source>Play</source>
        <translation>Přehrát</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pozastavit</translation>
    </message>
    <message>
        <source>Play/Pause</source>
        <translation>Přehrát/Pozastavit</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zastavit</translation>
    </message>
    <message>
        <source>Stop playing after current track</source>
        <translation>Zastavit přehrávání po této skladbě</translation>
    </message>
    <message>
        <source>Next track</source>
        <translation>Další skladba</translation>
    </message>
    <message>
        <source>Previous track</source>
        <translation>Předchozí skladba</translation>
    </message>
    <message>
        <source>Increase volume</source>
        <translation>Zvýšit hlasitost</translation>
    </message>
    <message>
        <source>Decrease volume</source>
        <translation>Snížit hlasitost</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Ztlumit</translation>
    </message>
    <message>
        <source>Seek forward</source>
        <translation>Přetočit vpřed</translation>
    </message>
    <message>
        <source>Seek backward</source>
        <translation>Přetočit zpět</translation>
    </message>
</context>
<context>
    <name>LastFm</name>
    <message>
        <source>Authentication failed</source>
        <translation>Ověření selhalo</translation>
    </message>
</context>
<context>
    <name>LastFmLoginDialog</name>
    <message>
        <source>Log in to %1</source>
        <translation>Přihlásit se do %1</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Uživatelské jméno:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>&amp;Heslo:</translation>
    </message>
    <message>
        <source>Signup for a %1 account</source>
        <translation>Přihlásit %1 účet</translation>
    </message>
    <message>
        <source>Forgot your &lt;a href=&apos;%1&apos;&gt;username&lt;/a&gt; or &lt;a href=&apos;%2&apos;&gt;password&lt;/a&gt;?</source>
        <translation>Zapomněl jste &lt;a href=&apos;%1&apos;&gt;uživatelské jméno&lt;/a&gt; nebo &lt;a href=&apos;%2&apos;&gt;heslo&lt;/a&gt;?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>&amp;Zpět</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Jít na předchozí zobrazení</translation>
    </message>
    <message>
        <source>&amp;Info</source>
        <translation>&amp;Informace</translation>
    </message>
    <message>
        <source>Show information about the current track</source>
        <translation>Zobrazit informace o této skladbě</translation>
    </message>
    <message>
        <source>P&amp;revious</source>
        <translation>&amp;Předchozí</translation>
    </message>
    <message>
        <source>Go back to the previous track</source>
        <translation>Jít zpět na předchozí skladbu</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Další</translation>
    </message>
    <message>
        <source>Skip to the next track</source>
        <translation>Přeskočit na další skladbu</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Přehrát</translation>
    </message>
    <message>
        <source>Start playback</source>
        <translation>Začít přehrávat</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>&amp;Celá obrazovka</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Zobrazit na celou obrazovku</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Odstranit</translation>
    </message>
    <message>
        <source>Remove the selected tracks from the playlist</source>
        <translation>Odstranit vybrané skladby ze seznamu skladeb</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Přesunout &amp;nahoru</translation>
    </message>
    <message>
        <source>Move up the selected tracks in the playlist</source>
        <translation>Posunout nahoru vybrané skladby v seznamu skladeb</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Přesunout &amp;dolů</translation>
    </message>
    <message>
        <source>Move down the selected tracks in the playlist</source>
        <translation>Posunout dolů vybrané skladby v seznamu skladeb</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Ukončit</translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Nashledanou</translation>
    </message>
    <message>
        <source>&amp;Change collection folder...</source>
        <translation>&amp;Změnit složku s hudební sbírkou...</translation>
    </message>
    <message>
        <source>Choose a different music collection folder</source>
        <translation>Vyberte odlišný adresář s hudební sbírkou</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>&amp;Internetová stránka</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>%1 na webu</translation>
    </message>
    <message>
        <source>Make a &amp;donation</source>
        <translation>Dát autorovi &amp;příspěvek</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Podpořte, prosím, probíhající vývoj %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;O programu</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Informace o %1</translation>
    </message>
    <message>
        <source>&amp;Clear</source>
        <translation>&amp;Smazat</translation>
    </message>
    <message>
        <source>Remove all tracks from the playlist</source>
        <translation>Vyprázdnit seznam skladeb</translation>
    </message>
    <message>
        <source>&amp;Shuffle</source>
        <translation>&amp;Zamíchat</translation>
    </message>
    <message>
        <source>Random playlist mode</source>
        <translation>&amp;Náhodný režim</translation>
    </message>
    <message>
        <source>&amp;Repeat</source>
        <translation>&amp;Opakovat</translation>
    </message>
    <message>
        <source>Play first song again after all songs are played</source>
        <translation>Přehrát první skladbu poté, co byly odehrány všechny skladby</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Ztlumit hlasitost</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>&amp;Program</translation>
    </message>
    <message>
        <source>&amp;Playback</source>
        <translation>&amp;Přehrávání</translation>
    </message>
    <message>
        <source>Play&amp;list</source>
        <translation>&amp;Seznam skladeb</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Pohled</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Nápověda</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Stiskněte %1 pro zvýšení hlasitosti, %2 pro snížení.</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otevírám %1</translation>
    </message>
    <message>
        <source>Updating collection...</source>
        <translation>Obnovuji sbírku...</translation>
    </message>
    <message>
        <source>Updating collection - %1%</source>
        <translation>Obnovuji sbírku - %1%</translation>
    </message>
    <message>
        <source>Collection updated</source>
        <translation>Sbírka obnovena</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Kritická chyba: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Chyba: %1</translation>
    </message>
    <message>
        <source>Leave &amp;Full Screen</source>
        <translation>Opustit zobrazení na &amp;celou obrazovku</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Zbývající čas: %1</translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Hlasitost na %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Hlasitost je ztlumena</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Hlasitost není ztlumená</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Dostat plnou verzi</translation>
    </message>
    <message>
        <source>%1 version %2 is now available.</source>
        <translation>%1 verze %2 je nyní dostupná.</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Připomenout později</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Aktualizovat</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Okno</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation>&amp;Zmenšit</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zavřít</translation>
    </message>
    <message>
        <source>Buy %1...</source>
        <translation>Koupit %1...</translation>
    </message>
    <message>
        <source>&amp;Stop After This Track</source>
        <translation>&amp;Zastavit po této skladbě</translation>
    </message>
    <message>
        <source>&amp;Scrobbling</source>
        <translation>&amp;Odesílání informací</translation>
    </message>
    <message>
        <source>Send played tracks titles to %1</source>
        <translation>Poslat názvy přehrávaných skladeb %1</translation>
    </message>
    <message>
        <source>&amp;Log Out from %1</source>
        <translation>&amp;Odhlásit se z %1</translation>
    </message>
    <message>
        <source>&amp;Report an Issue...</source>
        <translation>&amp;Nahlásit chybu...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>%1 finished scanning your music collection</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Love %1? Rate it!</source>
        <translation>&amp;Líbí se %1? Ohodnotit!</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Drop items here</source>
        <translation>Položky upusťte zde</translation>
    </message>
    <message>
        <source>Playlist finished</source>
        <translation>Seznam skladeb dokončen</translation>
    </message>
    <message>
        <source>This is just the demo version of %1.</source>
        <translation>Toto je pouze demoverze %1.</translation>
    </message>
    <message>
        <source>It allows you to play a few tracks so you can test the application and see if it works for you.</source>
        <translation>Umožňuje vám prehrát několik skladeb, takže můžete program vyzkoušet a vidět, jestli pracuje tak, jak má.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Pokračovat</translation>
    </message>
    <message>
        <source>Get the full version</source>
        <translation>Získejte plnou verzi</translation>
    </message>
</context>
<context>
    <name>MessageWidget</name>
    <message>
        <source>A new version of %1 is available!</source>
        <translation>Nová verze %1 je k dispozici!</translation>
    </message>
    <message>
        <source>%1 %2 is now available. You have %3.</source>
        <translation>%1 %2 je nyní k dispozici. Vy máte %3.</translation>
    </message>
    <message>
        <source>Would you like to download it now?</source>
        <translation>Chcete ji nyní stáhnout?</translation>
    </message>
    <message>
        <source>Skip This Version</source>
        <translation>Přeskočit tuto verzi</translation>
    </message>
    <message>
        <source>Remind Me Later</source>
        <translation>Připomenout později</translation>
    </message>
    <message>
        <source>Install Update</source>
        <translation>Nainstalovat aktualizaci</translation>
    </message>
</context>
<context>
    <name>PasteLineEdit</name>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
</context>
<context>
    <name>PlaylistModel</name>
    <message>
        <source>This demo is limited to only %1 tracks in the playlist.</source>
        <translation>Demoverze je omezena pouze na %1 skladeb v seznamu skladeb.</translation>
    </message>
</context>
<context>
    <name>PlaylistView</name>
    <message>
        <source>Playlist is empty</source>
        <translation>Seznam skladeb je prázdný</translation>
    </message>
    <message>
        <source>%1 tracks - Total length is %2</source>
        <translation>%1 skladeb - Celková  délka je %2</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Hledat</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Your search had no results.</source>
        <translation>Vaše hledání nepřineslo žádné výsledky.</translation>
    </message>
</context>
<context>
    <name>TrackListView</name>
    <message>
        <source>Tracks</source>
        <translation>Skladby</translation>
    </message>
</context>
</TS>